@@ -30,8 +30,9 @@ extensions = [
 ]
 
 # openstackdocstheme options
-repository_name = 'openstack/magnum'
-use_storyboard = True
+openstackdocs_repo_name = 'openstack/magnum'
+openstackdocs_pdf_link = True
+openstackdocs_use_storyboard = False
 
 config_generator_config_file = '../../etc/magnum/magnum-config-generator.conf'
 sample_config_basename = '_static/magnum'
@@ -50,7 +51,7 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 # General information about the project.
-copyright = u'2013, OpenStack Foundation'
+copyright = '2013, OpenStack Foundation'
 
 # If true, '()' will be appended to :func: etc. cross-reference text.
 add_function_parentheses = True
@@ -60,7 +61,7 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
 
 # -- Options for HTML output --------------------------------------------------
 
@@ -79,8 +80,8 @@ htmlhelp_basename = 'magnumdoc'
 latex_documents = [
     ('index',
      'doc-magnum.tex',
-     u'magnum Documentation',
-     u'OpenStack Foundation', 'manual'),
+     'magnum Documentation',
+     'OpenStack Foundation', 'manual'),
 ]
 
 # If false, no module index is generated.
