@@ -44,7 +44,12 @@ class KeystoneClientV3(object):
     def auth_url(self):
         # FIXME(pauloewerton): auth_url should be retrieved from keystone_auth
         # section by default
-        return CONF[ksconf.CFG_LEGACY_GROUP].auth_uri.replace('v2.0', 'v3')
+        conf = CONF[ksconf.CFG_LEGACY_GROUP]
+        auth_uri = (getattr(conf, 'www_authenticate_uri', None) or
+                    getattr(conf, 'auth_uri', None))
+        if auth_uri:
+            auth_uri = auth_uri.replace('v2.0', 'v3')
+        return auth_uri
 
     @property
     def auth_token(self):
@@ -258,14 +263,16 @@ class KeystoneClientV3(object):
                                                 domain_id=domain_id)
         return user
 
-    def delete_trustee(self, trustee_id):
+    def delete_trustee(self, trustee_user_id):
+        if trustee_user_id is None:
+            return
         try:
-            self.domain_admin_client.users.delete(trustee_id)
+            self.domain_admin_client.users.delete(trustee_user_id)
         except kc_exception.NotFound:
             pass
         except Exception:
             LOG.exception('Failed to delete trustee')
-            raise exception.TrusteeDeleteFailed(trustee_id=trustee_id)
+            raise exception.TrusteeDeleteFailed(trustee_id=trustee_user_id)
 
     def get_validate_region_name(self, region_name):
         if region_name is None:
