@@ -19,8 +19,6 @@ The IDs each comprise 12 (lower-case) alphanumeric characters.
 import base64
 import uuid
 
-import six
-
 from magnum.i18n import _
 
 
@@ -30,7 +28,7 @@ def _to_byte_string(value, num_bits):
     Padding is added at the end (i.e. after the least-significant bit) if
     required.
     """
-    shifts = six.moves.xrange(num_bits - 8, -8, -8)
+    shifts = range(num_bits - 8, -8, -8)
     byte_at = lambda off: ((value >> off  # noqa: E731
                             if off >= 0 else value << -off) & 0xff)
     return ''.join(chr(byte_at(offset)) for offset in shifts)
@@ -41,7 +39,7 @@ def get_id(source_uuid):
 
     The supplied UUID must be a version 4 UUID object.
     """
-    if isinstance(source_uuid, six.string_types):
+    if isinstance(source_uuid, str):
         source_uuid = uuid.UUID(source_uuid)
     if source_uuid.version != 4:
         raise ValueError(_('Invalid UUID version (%d)') % source_uuid.version)
@@ -50,12 +48,9 @@ def get_id(source_uuid):
     # (see RFC4122, Section 4.4)
     random_bytes = _to_byte_string(source_uuid.time, 60)
     # The first 12 bytes (= 60 bits) of base32-encoded output is our data
-    encoded = base64.b32encode(six.b(random_bytes))[:12]
+    encoded = base64.b32encode(random_bytes.encode('latin-1'))[:12]
 
-    if six.PY3:
-        return encoded.lower().decode('utf-8')
-    else:
-        return encoded.lower()
+    return encoded.lower().decode('utf-8')
 
 
 def generate_id():
