@@ -14,7 +14,6 @@
 
 from oslo_log import log as logging
 from oslo_utils import encodeutils
-import six
 
 from magnum.common import cert_manager
 from magnum.common import exception
@@ -26,7 +25,7 @@ import os
 import shutil
 import tempfile
 
-CONDUCTOR_CLIENT_NAME = six.u('Magnum-Conductor')
+CONDUCTOR_CLIENT_NAME = 'Magnum-Conductor'
 
 LOG = logging.getLogger(__name__)
 CONF = magnum.conf.CONF
