@@ -22,8 +22,8 @@ Create Date: 2015-10-14 16:21:57.229436
 revision = '417917e778f5'
 down_revision = '33ef79969018'
 
-from alembic import op
-import sqlalchemy as sa
+from alembic import op  # noqa: E402
+import sqlalchemy as sa  # noqa: E402
 
 
 def upgrade():
