@@ -23,15 +23,12 @@ down_revision = '456126c6c9e9'
 
 from alembic import op  # noqa: E402
 
-from oslo_db.sqlalchemy.types import String  # noqa: E402
+from sqlalchemy.types import String  # noqa: E402
 
 import sqlalchemy as sa  # noqa: E402
 
-from sqlalchemy.dialects.mysql import TINYTEXT  # noqa: E402
-
 
 def upgrade():
     op.add_column('bay',
                   sa.Column('discovery_url',
-                            String(255, mysql_ndb_type=TINYTEXT),
-                            nullable=True))
+                            String(255), nullable=True))
