@@ -1,5 +1,3 @@
-#!/bin/sh
-
 step="enable-node-problem-detector"
 printf "Starting to run ${step}\n"
 
@@ -127,7 +125,7 @@ EOF
     }
 
     echo "Waiting for Kubernetes API..."
-    until  [ "ok" = "$(curl --silent http://127.0.0.1:8080/healthz)" ]
+    until  [ "ok" = "$(kubectl get --raw='/healthz')" ]
     do
         sleep 5
     done
@@ -241,7 +239,7 @@ EOF
 
 function enable_magnum_auto_healer {
     echo "Installing magnum_auto_healer"
-    image_prefix=${CONTAINER_INFRA_PREFIX:-docker.io/k8scloudprovider/}
+    image_prefix=${CONTAINER_INFRA_PREFIX:-registry.k8s.io/provider-os/}
     image_prefix=${image_prefix%/}
     magnum_auto_healer_manifest=/srv/magnum/kubernetes/manifests/magnum_auto_healer.yaml
 
